<template>
  <GasBillRechargeBaseForm ref="formRef" v-model:form="preSetForm">
    <NutFormItem label="备注信息" class="bole-form-item" prop="remark">
      <NutInput
        v-model.trim="preSetForm.remark"
        class="bole-input-text"
        placeholder="请输入备注信息"
        type="text"
        max-length="30"
      />
    </NutFormItem>
    <div class="common-content">
      <NutButton class="recharge-button" type="primary" @click="handleNext">
        <div class="recharge-button-inner">
          <div class="recharge-button-text">立即充值</div>
        </div>
      </NutButton>
      <NutButton class="recharge-button" type="primary" plain @click="goToPrevious">
        <div class="recharge-button-inner">
          <div class="recharge-button-text">返回</div>
        </div>
      </NutButton>
    </div>
  </GasBillRechargeBaseForm>
</template>

<script setup lang="ts">
import { Button as NutButton, FormItem as NutFormItem, Input as NutInput } from '@nutui/nutui-taro';
import { reactive, ref, computed, watch } from 'vue';
import GasBillRechargeBaseForm from './GasBillRechargeBaseForm.vue';
import { useGasBillRechargeContext } from './context';
import {
  useLifeRechargeContext,
  LifeRechargeConstants,
  AddUpdateUserAccountInput,
} from '@life-payment/core-vue';
import { useAddUpdateUserAccount } from '../../hooks';

defineOptions({
  name: 'GasBillRechargeStep2',
});

const { preSetForm, goToPrevious, goToNext } = useGasBillRechargeContext();

const formRef = ref<any>(null);

function handleNext() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      handleAddUpdateUserAccount();
    }
  });
}

const { addUpdateUserAccount } = useAddUpdateUserAccount();
const { blLifeRecharge } = useLifeRechargeContext();

async function handleAddUpdateUserAccount() {
  try {
    let params: AddUpdateUserAccountInput = {
      userId: blLifeRecharge.accountModel.userId,
      lifePayType: LifeRechargeConstants.LifePayOrderTypeEnum.燃气订单,
      content: preSetForm.gasAccount,
      province: preSetForm.areaList?.[0] ?? '',
      city: preSetForm.areaList?.[1] ?? '',
      extraProperties: JSON.stringify(preSetForm),
      operators: preSetForm.gasOrgType,
      remark: preSetForm.remark,
    };
    await addUpdateUserAccount(params);
    preSetForm.areaList = [];
    preSetForm.gasAccount = '';
    preSetForm.remark = '';
    preSetForm.gasOrgType = '' as any;
    goToNext();
  } catch (error) {}
}
</script>
